# TOPSIS

Code by: Kashish Mehra

<hr style = "border:2px solid gray"> </hr>

## Introduction

The Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) developed by Hwang &
Yoon,is a technique to evaluate the performance of alternatives through the similarity with the ideal
solution. According to this technique, the best alternative would be one that is closest to the positive-ideal
solution and farthest from the negative-ideal solution. The positive-ideal solution is one that maximizes the
benefit criteria and minimizes the cost criteria. The negative-ideal solution maximizes the cost criteria and
minimizes the benefit criteria. In summary, the positive-ideal solution is composed of all best values attainable
of criteria, and the negative-ideal solution consists of all the worst values attainable of criteria. 


## How to run

#### Before running, make sure you have pandas installed on your system

Open Terminal and input the following commands


>> pip install Topsis-Kashish-101983051



>> python
>>>from topsis.code import topsis
>>>topsis("data.csv","1,1,1,2","+,+,-,+","result.csv")

## Sample Input

This input was used to test the module

<table><thead><tr><th>Model</th><th>Corr</th><th>Rseq</th><th>RMSE</th><th>Accuracy</th></tr></thead><tbody><tr><td>M1</td><td>0.79</td><td>0.62</td><td>1.25</td><td>60.89</td></tr><tr><td>M2</td><td>0.66</td><td>0.44</td><td>2.89</td><td>63.07</td></tr><tr><td>M3</td><td>0.56</td><td>0.31</td><td>1.57</td><td>62.87</td></tr><tr><td>M4</td><td>0.82</td><td>0.67</td><td>2.68</td><td>70.19</td></tr><tr><td>M5</td><td>0.75</td><td>0.56</td><td>1.3</td><td>80.39</td></tr></tbody></table>

## Output 


<table><thead><tr><th>Model</th><th align="right">Corr</th><th align="center">Rseq</th><th>RMSE</th><th>Accuracy</th><th>Topsis Score</th><th>Rank</th></tr></thead><tbody><tr><td>M1</td><td align="right">0.79</td><td align="center">0.62</td><td>1.25</td><td>60.89</td><td>0.639133</td><td>2.0</td></tr><tr><td>M2</td><td align="right">0.66</td><td align="center">0.44</td><td>2.89</td><td>63.07</td><td>0.212592</td><td>5.0</td></tr><tr><td>M3</td><td align="right">0.56</td><td align="center">0.31</td><td>1.57</td><td>62.87</td><td>0.407846</td><td>4.0</td></tr><tr><td>M4</td><td align="right">0.82</td><td align="center">0.67</td><td>2.68</td><td>70.19</td><td>0.519153</td><td>3.0</td></tr><tr><td>M5</td><td align="right">0.75</td><td align="center">0.56</td><td>1.3</td><td>80.39</td><td>0.828267</td><td>1.0</td></tr></tbody></table>


## License

© 2020 Kashish Mehra

This repository is licensed under the MIT license. See LICENSE for details.